require(MASS)

data("birthwt")
head(birthwt)
str(birthwt)
summary(birthwt)


apply(birthwt, 2, function(x) sum(is.na(x)))

dim(birthwt)

# Recoding and checking variables
birthwt <- within(birthwt, {
  +   low <- factor(low, labels=c("No","Yes"))
  +   race <- factor(race, labels=c("White","Black","Other"))
  +   smoke <- factor(smoke, labels=c("No","Yes"))
  +   ui <- factor(ui, labels=c("No","Yes"))
  +   ht <- factor(ht, labels=c("No","Yes"))
  + 
    })

#treating as factors
idx <- sapply(birthwt, is.numeric)

#Plotting
boxplot(apply(birthwt[,idx], 2, scale))

#Summarising data
library(Hmisc)
summary(low ~ ., data=birthwt, method="reverse", overall=TRUE)
summary(bwt ~ ., data=birthwt)
summary(low ~ smoke + ht + ui, data=birthwt, fun=table)

#Multivariate display
library(lattice)
parallel(birthwt[,idx], groups=birthwt$low, horizontal.axis=FALSE)
print(parallel(~ birthwt[,idx] | smoke, data=birthwt, groups=low,
                 +                lty=1:2, col=c("gray80","gray20")))
splom(~ birthwt[,idx], data=birthwt, jitter.x=TRUE, cex=.6,
      +       groups=low, panel=panel.superpose, grid=TRUE,
      +       axis.text.cex=0.6, xlab="", pch=c(2,6))
      

library(Acinonyx)
attach(birthwt)
iplot(lwt, bwt)
iplot(smoke, bwt)
ihist(bwt)
ibar(factor(ftv))
detach(birthwt)

#Dealing with continous variable
library(lattice)
print(xyplot(bwt ~ lwt, data=birthwt, type=c("p", "smooth")))
with(birthwt, cor.test(bwt, lwt))

with(birthwt, cor.test(bwt, lwt, method="spearman"))

#Comparing two means
t.test(bwt ~ smoke, data=birthwt, var.equal=TRUE)
t.test(bwt ~ smoke, data=birthwt)
with(birthwt, tapply(bwt, smoke, var))

with(birthwt, qqnorm(bwt[smoke=="No"], main=""))
with(birthwt, qqnorm(bwt[smoke=="Yes"], main=""))

#Graphical summary
print(bwplot(bwt ~ smoke, data=birthwt))
print(histogram(~ bwt | smoke, data=birthwt, type="count"))

#Re-randomization
library(coin)
independence_test(bwt ~ smoke, data=birthwt, distribution="exact")

#Comparing more than two means
fm <- bwt ~ race
aov.fit <- aov(fm, data=birthwt)
summary(aov.fit)

plot(aov.fit, which=1)
model.tables(aov.fit)

plot.design(fm, data=birthwt)

#likewise two way anova
summary(aov.fit2 <- aov(bwt ~ smoke * ht, data=birthwt))
        
aov.fit3 <- aov(bwt ~ smoke + ht, data=birthwt)
anova(aov.fit2, aov.fit3)        

summary(aov.fit4 <- update(aov.fit3, . ~ . * race))

with(birthwt, pairwise.t.test(bwt, race))

aov.fit5 <- update(aov.fit3, . ~ . + race)
model.tables(aov.fit5)

se.contrast(aov.fit5, list(birthwt$race=="White",
                           +                            birthwt$race=="Black"))

TukeyHSD(aov.fit5, which="race")

plot(TukeyHSD(aov.fit5, which="race"))
     
#Linear regression
lm.fit5 <- lm(bwt ~ smoke + ht + race, data=birthwt)
summary(lm.fit5)

anova(lm.fit5)

plot(lm.fit5, which=4)

head(model.matrix(lm.fit5))

head(birthwt[,c("smoke","ht","race")])

all.means <- aggregate(bwt ~ smoke + ht + race,
                       +                        data=birthwt, FUN=mean)
print(xyplot(bwt ~ smoke | race, data=all.means, groups=ht,
               +              layout=c(3,1), type=c("p","l"), auto.key=TRUE))

#Continous predictor
fm <- bwt ~ (smoke + ht) * scale(age, scale=F) + race
lm.fit6 <- lm(fm, data=birthwt)
summary(lm.fit6)
